<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'weLaunch' ) && ! class_exists( 'Redux' ) ) {
        return;
    }

    if( class_exists( 'weLaunch' ) ) {
        $framework = new weLaunch();
    } else {
        $framework = new Redux();
    }

    $options = get_option('woocommerce_ultimate_pricing_options');

    $levelsMax = 10;
    if(class_exists('WooCommerce_Reward_Points')) {
        $reward_points_options = get_option('woocommerce_reward_points_options');
        
        if(isset($reward_points_options['levelsMax']) && !empty($reward_points_options['levelsMax'])) {
            $levelsMax = $reward_points_options['levelsMax'];
        }
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "woocommerce_ultimate_pricing_options";

    $args = array(
        'opt_name' => 'woocommerce_ultimate_pricing_options',
        'use_cdn' => TRUE,
        'dev_mode' => FALSE,
        'display_name' => __('WooCommerce Ultimate Pricing', 'woocommerce-ultimate-pricing'),
        'display_version' => '1.1.4',
        'page_title' => __('WooCommerce Ultimate Pricing', 'woocommerce-ultimate-pricing'),
        'update_notice' => TRUE,
        'intro_text' => '',
        'footer_text' => '&copy; ' . date('Y') . ' weLaunch',
        'admin_bar' => false,
        'menu_type' => 'submenu',
        'menu_title' => __('Ultimate Pricing', 'woocommerce-ultimate-pricing'),
        'allow_sub_menu' => TRUE,
        'page_parent' => 'woocommerce',
        'customizer' => FALSE,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    global $weLaunchLicenses;
    if( (isset($weLaunchLicenses['woocommerce-ultimate-pricing']) && !empty($weLaunchLicenses['woocommerce-ultimate-pricing'])) || (isset($weLaunchLicenses['woocommerce-plugin-bundle']) && !empty($weLaunchLicenses['woocommerce-plugin-bundle'])) ) {
        $args['display_name'] = '<span class="dashicons dashicons-yes-alt" style="color: #9CCC65 !important;"></span> ' . $args['display_name'];
    } else {
        $args['display_name'] = '<span class="dashicons dashicons-dismiss" style="color: #EF5350 !important;"></span> ' . $args['display_name'];
    }

    $discountPriceVariablesToUse = '
        {{fixedDiscountTotal}}<br>
        {{percentageDiscountTotal}}<br>
        {{discountRateTotal}}<br>
        {{discountPercentageTotal}}<br>
        {{discountRulesText}}<br>
        {{oldPrice}}<br>
        {{newPrice}}<br>
    ';

    
    $framework::setArgs( $opt_name, $args );


    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'General', 'woocommerce-ultimate-pricing' ),
        'id'     => 'general',
        'desc'   => esc_html__( 'Need support? Please use the comment function on codecanyon.', 'woocommerce-ultimate-pricing' ),
        'icon'   => 'el el-home',
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'General', 'woocommerce-ultimate-pricing' ),
        'desc'       => sprintf('%s<a href="' . admin_url('tools.php?page=welaunch-framework') . '">%s</a>', esc_html__( 'To get auto updates please ', 'woocommerce-ultimate-pricing' ), esc_html__( 'register your License here.', 'woocommerce-ultimate-pricing' )),
        'id'         => 'general-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'enable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'customUserRolePrices',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Enable Custom User Role Prices', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( 'Enable custom prices per product per user role. You can use the importer or set custom user role prices in backend when you edit.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'customUserRolePricesDisableBackend',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Disable Custom User Role Prices Backend', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( 'We recommend to ONLY use the importer, cause editing each product manually in backend affects performance.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'performanceOnlyWooPages',
                'type'     => 'checkbox',
                'title'    => esc_html__('Performance: Scripts & Stylings', 'woocommerce-shop-look' ),
                'subtitle' => esc_html__('Only execute CSS & JS Files on product pages. Disable when you use shortcodes.', 'woocommerce-shop-look' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'excel2007',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Use Excel 2007', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'If you can not work with xlsx (Excel 2007 and higher) files, check this. You then can work with normal .xls files.', 'woocommerce-ultimate-pricing' ),
                'default'  => '0',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'   => 'importer',
                'type' => 'info',
                'desc' => 
                    '<div style="text-align:center;">
                        <p>' . esc_html__('To import products use the Excel file you get when clicking on Export Prices button below.', 'woocommerce-ultimate-pricing') . '</p>
                        <a href="' . get_admin_url() . 'edit.php?post_type=stores&page=wordpress_store_locator_options_options&woocommerce-ultimate-pricing-export" class="button button-success">' . esc_html__('Export Prices', 'woocommerce-ultimate-pricing') . '</a>
                        <a href="' . get_admin_url() . 'admin.php?page=woocommerce-ultimate-pricing-importer" class="button button-primary">' . esc_html__('Import Prices', 'woocommerce-ultimate-pricing') . '</a>  
                    </div>',
            ),
       )
    ) );

    // Product Discounts
    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'Product Discounts', 'woocommerce-ultimate-pricing' ),
        'id'     => 'productDiscounts',
        'icon'   => 'el el-tags',
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'General', 'woocommerce-ultimate-pricing' ),
        'id'         => 'productDiscountsGeneral',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'productDiscountsEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Product Discounts', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'productDiscountsCount',
                'type'     => 'spinner',
                'title'    => esc_html__('Product Discount Rules Count', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Limit the number of global product pricing rules to decrease the load time. Reload the settings panel after changing.', 'woocommerce-ultimate-pricing'), 
                'default'  => '10',
                'min'      => '1',
                'step'     => '1',
                'max'      => '200',
                'required' => array('productDiscountsEnabled', 'equals', '1' ),
            ),
        )
    ) );

    // Badge
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Badge', 'woocommerce-ultimate-pricing'),
        'id'         => 'productDiscountsBadge',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'productDiscountsBadgeEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Show  Bage', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Enable to show a  badge after the price.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'productDiscountsBadgeDisplay',
                'type'     => 'select',
                'title'    => esc_html__('Display', 'woocommerce-ultimate-pricing'),
                'multi'    => true,
                'subtitle' => esc_html__('Specify if it should show on single, category or both pages.', 'woocommerce-ultimate-pricing'),
                'options'  => array( 
                    'singleProduct' => esc_html__('Single Product Pages', 'woocommerce-ultimate-pricing'),
                    'productCategory' => esc_html__('Product Cateories', 'woocommerce-ultimate-pricing'),
                    'cart' => esc_html__('Cart Page', 'woocommerce-ultimate-pricing'),
                    'checkout' => esc_html('Checkout', 'woocommerce-ultimate-pricing'),
                ),
                'default'  => array('singleProduct', 'productCategory', 'cart', 'checkout'),
                'required' => array('productDiscountsBadgeEnabled','equals','1'),
            ),
            array(
                'id'       => 'productDiscountsBadgeText',
                'type'     => 'text',
                'title'    => esc_html__(' Bage Text', 'woocommerce-ultimate-pricing'),
                'subtitle' => esc_html__('Text that will show in the badge. Variables you can use: ', 'woocommerce-ultimate-pricing') . $discountPriceVariablesToUse,
                'default'  => esc_html__('Save {{discountPercentageTotal}} ({{discountRateTotal}})', 'woocommerce-ultimate-pricing'),
                'required' => array('productDiscountsBadgeEnabled','equals','1'),
            ),
            array(
                'id'       => 'productDiscountsBadgeTooltip',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show tooltip text', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Shows the configured tooltip text on badge hover.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
                'required' => array('productDiscountsBadgeEnabled','equals','1'),
            ),
            array(
                'id'      => 'productDiscountsBadgeBackgroundColor',
                'type'      => 'color',
                'title'    => esc_html__(' Badge Background Color', 'woocommerce-ultimate-pricing'), 
                'default'   => '#F44336',
                'required' => array('productDiscountsBadgeEnabled','equals','1'),
            ),
            array(
                'id'      => 'productDiscountsBadgeTextColor',
                'type'      => 'color',
                'title'    => esc_html__(' Badge Text Color', 'woocommerce-ultimate-pricing'), 
                'default'   => '#ffffff',
                'required' => array('productDiscountsBadgeEnabled','equals','1'),
            ),
        )
    ));

    // ToolTip
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Tooltip', 'woocommerce-ultimate-pricing' ),
        'id'         => 'tooltip',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'productDiscountsTooltipEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Tooltip', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( 'Tooltip shows next to price with indication of current applied productDiscount rules.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'productDiscountsTooltipText',
                'type'     => 'text',
                'title'    => esc_html__( 'Tooltip Text', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__('Default tooltip text, that will show beside the price. Variables you can use: ', 'woocommerce-ultimate-pricing') . $discountPriceVariablesToUse,
                'default' => esc_html__('Save {{discountRateTotal}}! {{discountRulesText}}', 'woocommerce-ultimate-pricing'), 
                'required' => array('productDiscountsTooltipEnabled', 'equals', '1'),
            ),
            array(
                'id'       => 'productDiscountsTooltipSingleDiscountRuleText',
                'type'     => 'text',
                'title'    => esc_html__( 'Single Discount Rules Text', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__('Used for all productDiscount rules, that will apply each. This builds the {{discountRulesText}} string. Variables you can use:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountRate}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountTitle}}', 'woocommerce-ultimate-pricing'),
                'default' => esc_html__('{{discountTitle}}', 'woocommerce-ultimate-pricing'), 
                'required' => array('productDiscountsTooltipEnabled', 'equals', '1'),
            ),
            array(
                'id'       => 'productDiscountsTooltipDiscountRulesAppendix',
                'type'     => 'text',
                'title'    => esc_html__('Discount Rule Appendix', 'woocommerce-advanced-categories'),
                'subtitle' => esc_html__('If more than 1 rule applies.'),
                'default'  => ' & ',
                'required' => array('productDiscountsTooltipEnabled', 'equals', '1'),
            ),

            array(
                'id'       => 'productDiscountsTooltipIconEnabled',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show tooltip Icon', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Shows an extra tooltip icon behind the badge.', 'woocommerce-ultimate-pricing' ),
                'default'  => 0,
                'required' => array('productDiscountsTooltipEnabled','equals','1'),
            ),
            array(
                'id'       => 'productDiscountsTooltipDisplay',
                'type'     => 'select',
                'title'    => esc_html__('Display', 'woocommerce-ultimate-pricing'),
                'multi'    => true,
                'subtitle' => esc_html__('Specify if it should show on single, category or both pages.', 'woocommerce-ultimate-pricing'),
                'options'  => array( 
                    'singleProduct' => esc_html__('Single Product Pages', 'woocommerce-ultimate-pricing'),
                    'productCategory' => esc_html__('Product Cateories', 'woocommerce-ultimate-pricing'),
                    'cart' => esc_html__('Cart Page', 'woocommerce-ultimate-pricing'),
                    'checkout' => esc_html('Checkout', 'woocommerce-ultimate-pricing'),
                ),
                'default'  => array('singleProduct'),
                'required' => array('productDiscountsTooltipIconEnabled','equals','1'),
            ),
            array(
                'id'       => 'productDiscountsTooltipIcon',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__( 'Tooltip Icon', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__('SVG icon or image HTML works.', 'woocommerce-ultimate-pricing'), 
                'args'   => array(
                    'teeny'            => false,
                ),
                'default' => '', 
                'required' => array('productDiscountsTooltipIconEnabled', 'equals', '1'),
            ),
            array(
                'id'       => 'productDiscountsTooltipIconWidth',
                'type'     => 'spinner',
                'title'    => esc_html__('Tooltip Icon Width (px)', 'woocommerce-ultimate-pricing'),
                'default'  => '25',
                'min'      => '1',
                'step'     => '1',
                'max'      => '99999',
                'required' => array('productDiscountsTooltipIconEnabled', 'equals', '1'),
            ),
        )
    ) );    

    $productDiscountsCount = 10;
    if(isset($options['productDiscountsCount']) && !empty($options['productDiscountsCount'])) {
        $productDiscountsCount = $options['productDiscountsCount'];
    }
    
    for ($i=1; $i <= $productDiscountsCount; $i++) { 
        
        $customTitle = isset($options['productDiscountsRule' . $i . 'InternalName']) && !empty($options['productDiscountsRule' . $i . 'InternalName']) ? $options['productDiscountsRule' . $i . 'InternalName'] : esc_html__('Scenario ', 'woocommerce-ultimate-pricing') . $i;

        $framework::setSection( $opt_name, array(
            'title'      => $customTitle,
            'id'         => 'productDiscountRule' . $i,
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Enabled',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Enable', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__( 'Enable this Product Discount Rule.', 'woocommerce-ultimate-pricing' ),
                    'default'  => 0,
                ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Title',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Title', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this Rule a custom title, that can be used in the tooltip for example.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'InternalName',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Internal Name', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this Rule an internal name.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'TooltipText',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Tooltip Text', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Set a custom tooltip text to override the default tooltip text.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                // orer count + reviews made
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Type',
                    'type'     => 'select', 
                    'title'    => esc_html__('Discount Type', 'woocommerce-ultimate-pricing'),
                    'options'  => array(
                        'percentage' => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'fixed' => esc_html__('Fixed Amount Discount', 'woocommerce-ultimate-pricing'),
                        
                    ),
                    'default'  => 'percentage',
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                    array(
                        'id'       => 'productDiscountsRule' . $i . 'PercentageDiscount',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('productDiscountsRule' . $i . 'Enabled','equals', '1'), array('productDiscountsRule' . $i . 'Type', 'equals', 'percentage') ),
                    ),
                    array(
                        'id'       => 'productDiscountsRule' . $i . 'FixedDiscount',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Fixed Amount Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '9999999999999',
                        'required' => array( array('productDiscountsRule' . $i . 'Enabled','equals', '1'), array('productDiscountsRule' . $i . 'Type', 'equals', 'fixed') ),
                    ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Addable',
                    'type'     => 'checkbox',
                    'title'    => esc_html__( 'Is addable?', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__( 'When this is enabled and there are multiple product discount rules applied, then it will add them.', 'woocommerce-ultimate-pricing' ),
                    'default'  => 0,
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                // Apply For section
                array(
                    'id'        => 'productDiscountsRule' . $i . 'Roles',
                    'type'      => 'select',
                    'data'      => 'roles',
                    'multi'     => true,
                    'title'     => esc_html__('Apply for User Roles ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain user roles only.', 'woocommerce-ultimate-pricing'),
                    'required'  => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'productDiscountsRule' . $i . 'Categories',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_cat')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Categories', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on product categories only.', 'woocommerce-ultimate-pricing'),
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'productDiscountsRule' . $i . 'Tags',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_tag')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Tags', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on product tags only.', 'woocommerce-ultimate-pricing'),
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'productDiscountsRule' . $i . 'Products',
                    'type'      => 'select',
                    'data'      => 'posts',
                    'args'      => array('post_type' => array('product'), 'posts_per_page' => -1),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Products ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain products only', 'woocommerce-ultimate-pricing'),
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Level',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when User is at least Level X', 'woocommerce-ultimate-pricing'),
                    'subtitle' => __('You need our <a href="https://www.welaunch.io/en/product/woocommerce-reward-points/" target="_blank">WooCommerce Reward Points plugin</a> for this. 0 means disabled.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => $levelsMax,
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Reviews',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Rewiews Written', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply this discount rule only when certain amount of reviews have been written. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'productDiscountsRule' . $i . 'Orders',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Orders reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply this discount rule only when certain amount of orders have been made. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'productDiscountsRule' . $i . 'DateRange',
                    'type'     => 'text',
                    'class'    => 'woocommerce-ultimate-pricing-datepicker',
                    'title'    => esc_html__('Start & End Date', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Specify a date from when this discount should get applied on to.', 'woocommerce-ultimate-pricing'),
                    'default'  => '',
                    'required' => array('productDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
           )
        ) );
    }

    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'Cart Discounts', 'woocommerce-ultimate-pricing' ),
        'id'     => 'cartDiscounts',
        'icon'   => 'el el-shopping-cart',
    ) );

    // Cart Discounts
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'General', 'woocommerce-ultimate-pricing' ),
        'id'         => 'cartDiscountsGeneral',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'cartDiscountsEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Cart Discounts', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( '', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'cartDiscountsCount',
                'type'     => 'spinner',
                'title'    => esc_html__('Cart Discounts Count', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Limit the number of global cart discount rules to decrease the load time. Reload the settings panel after changing.', 'woocommerce-ultimate-pricing'), 
                'default'  => '10',
                'min'      => '1',
                'step'     => '1',
                'max'      => '200',
                'required' => array('cartDiscountsEnabled', 'equals', '1' ),
            ),
            array(
                'id'       => 'cartDiscountsExcludeTaxes',
                'type'     => 'checkbox', 
                'title'    => esc_html__('Exclude Taxes', 'woocommerce-ultimate-pricing'),
                'subtitle'    => esc_html__('No taxes are applied to cart discounts.', 'woocommerce-ultimate-pricing'),
                'default'  => 1,
                'required' => array('cartDiscountsEnabled','equals', '1' ),
            ),
            array(
                'id'       => 'cartDiscountsSubotalWithTaxes',
                'type'     => 'checkbox', 
                'title'    => esc_html__('Add Taxes to Subtotal Calculation', 'woocommerce-ultimate-pricing'),
                'subtitle'    => esc_html__('When disabled the subtotal will be used without taxes.', 'woocommerce-ultimate-pricing'),
                'default'  => 1,
                'required' => array('cartDiscountsEnabled','equals', '1' ),
            ),
            array(
                'id'       => 'cartDiscountsRoundDown',
                'type'     => 'checkbox', 
                'title'    => esc_html__('Round Discount Down', 'woocommerce-ultimate-pricing'),
                'subtitle'    => esc_html__('Round discounts down to full integer numbers.', 'woocommerce-ultimate-pricing'),
                'default'  => 0,
                'required' => array('cartDiscountsEnabled','equals', '1' ),
            ),
            
        )
    ) ); 

    $cartDiscountsCount = 10;
    if(isset($options['cartDiscountsCount']) && !empty($options['cartDiscountsCount'])) {
        $cartDiscountsCount = $options['cartDiscountsCount'];
    }
    
    for ($i=1; $i <= $cartDiscountsCount; $i++) { 
        
        $customTitle = isset($options['cartDiscountsRule' . $i . 'InternalName']) && !empty($options['cartDiscountsRule' . $i . 'InternalName']) ? $options['cartDiscountsRule' . $i . 'InternalName'] : esc_html__('Scenario ', 'woocommerce-ultimate-pricing') . $i;

        $framework::setSection( $opt_name, array(
            'title'      => $customTitle,
            'id'         => 'cartDiscountsRule' . $i,
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Enabled',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Enable', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__( 'Enable this cartDiscountsRule.', 'woocommerce-ultimate-pricing' ),
                    'default'  => 0,
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Title',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Title', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this cart discount Rule a custom title, that can be used in the tooltip for example.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'InternalName',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Internal Name', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this cart discount rule an internal name.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'TooltipText',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Tooltip Text', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Set a custom tooltip text to override the default tooltip text.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Type',
                    'type'     => 'select', 
                    'title'    => esc_html__('Discount Type', 'woocommerce-ultimate-pricing'),
                    'options'  => array(
                        'percentage' => esc_html__('Percentage Discount (Cart Subotal)', 'woocommerce-ultimate-pricing'),
                        'fixed' => esc_html__('Fixed Amount Discount', 'woocommerce-ultimate-pricing'),
                        'fixedTotal' => esc_html__('Fixed Amount Total', 'woocommerce-ultimate-pricing'),
                        'percentageTotalAppliedWithTax' => esc_html__('Percentage Amount of Applied Items with Tax', 'woocommerce-ultimate-pricing'),
                        'percentageTotalAppliedWithoutTax' => esc_html__('Percentage Amount of Applied Items without Tax', 'woocommerce-ultimate-pricing'),
                    ),
                    'default'  => 'percentage',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                    array(
                        'id'       => 'cartDiscountsRule' . $i . 'PercentageDiscount',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartDiscountsRule' . $i . 'Enabled','equals', '1'), array('cartDiscountsRule' . $i . 'Type', 'equals', 'percentage') ),
                    ),
                    array(
                        'id'       => 'cartDiscountsRule' . $i . 'PercentageTotalAppliedWithTaxPercentage',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartDiscountsRule' . $i . 'Enabled','equals', '1'), array('cartDiscountsRule' . $i . 'Type', 'equals', 'percentageTotalAppliedWithTax') ),
                    ),
                    array(
                        'id'       => 'cartDiscountsRule' . $i . 'PercentageTotalAppliedWithoutTaxPercentage',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartDiscountsRule' . $i . 'Enabled','equals', '1'), array('cartDiscountsRule' . $i . 'Type', 'equals', 'percentageTotalAppliedWithoutTax') ),
                    ),
                    array(
                        'id'       => 'cartDiscountsRule' . $i . 'FixedDiscount',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Fixed Amount Discount', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '9999999999999',
                        'required' => array( array('cartDiscountsRule' . $i . 'Enabled','equals', '1'), array('cartDiscountsRule' . $i . 'Type', 'equals', 'fixed') ),
                    ),
                    array(
                        'id'       => 'cartDiscountsRule' . $i . 'FixedTotal',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Fixed Total Amount', 'woocommerce-ultimate-pricing'),
                        'subtitle'    => esc_html__('The total price of the cart.', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '9999999999999',
                        'required' => array( array('cartDiscountsRule' . $i . 'Enabled','equals', '1'), array('cartDiscountsRule' . $i . 'Type', 'equals', 'fixedTotal') ),
                    ),

                array(
                    'id'        => 'cartDiscountsRule' . $i . 'FreeProducts',
                    'type'      => 'select',
                    'data'      => 'posts',
                    'args'      => array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Grant Products for Free ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Add / change these products to free (0 price).', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'FreeProductsQuantity',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Free Products Quantity', 'woocommerce-ultimate-pricing'),
                    'default'  => '1',
                    'min'      => '1',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1'),
                ),

                // Apply For section
                array(
                    'id'        => 'cartDiscountsRule' . $i . 'Roles',
                    'type'      => 'select',
                    'data'      => 'roles',
                    'multi'     => true,
                    'title'     => esc_html__('Apply for User Roles ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Only add this tab to specific products.', 'woocommerce-ultimate-pricing'),
                    'required'  => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Level',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when User is at least Level X', 'woocommerce-ultimate-pricing'),
                    'subtitle' => __('You need our <a href="https://www.welaunch.io/en/product/woocommerce-reward-points/" target="_blank">WooCommerce Reward Points plugin</a> for this. 0 means disabled.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => $levelsMax,
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'CartItemCount',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Items are in Cart', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of items are in cart. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'CartQuantityCount',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Quantity Count is Cart', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain quantity is in cart. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'CartSubtotal',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Cart Subtotal reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when a specific cart subtotal is reached. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Reviews',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Rewiews Written', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of reviews have been written. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartDiscountsRule' . $i . 'Orders',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Orders reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of orders have been made. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'cartDiscountsRule' . $i . 'DateRange',
                    'type'     => 'text',
                    'class'    => 'woocommerce-ultimate-pricing-datepicker',
                    'title'    => esc_html__('Start & End Date', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Specify a date from when this discount should get applied on to.', 'woocommerce-ultimate-pricing'),
                    'default'  => '',
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'        => 'cartDiscountsRule' . $i . 'Categories',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_cat')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Categories', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain product categories only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'cartDiscountsRule' . $i . 'Tags',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_tag')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Tags', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain product tags only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'cartDiscountsRule' . $i . 'Products',
                    'type'      => 'select',
                    'data'      => 'posts',
                    'args'      => array('post_type' => array('product'), 'posts_per_page' => -1),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Products ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain products only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartDiscountsRule' . $i . 'Enabled','equals', '1' ),
                ),
           )
        ) );
    }


    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'Tiered Pricing', 'woocommerce-ultimate-pricing' ),
        'id'     => 'tieredPricing',
        'icon'   => 'el el-align-left',
    ) );

    // Tiered Pricing
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Tiered Pricing', 'woocommerce-ultimate-pricing' ),
        'id'         => 'tieredPricingGeneral',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'tieredPricingEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Tiered Pricing', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'tieredPricingCount',
                'type'     => 'spinner',
                'title'    => esc_html__('Tiered Pricing Count', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Limit the number of global tiered pricing rules to decrease the load time. Reload the settings panel after changing.', 'woocommerce-ultimate-pricing'), 
                'default'  => '10',
                'min'      => '1',
                'step'     => '1',
                'max'      => '200',
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
            array(
                'id'       => 'tieredPricingDisableBackend',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Disable Tiered Pricing Backend', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( 'We recommend to ONLY use the importer, cause editing each product manually in backend affects performance.', 'woocommerce-ultimate-pricing' ),
                'default'  => 0,
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
            array(
                'id'       =>'tieredPricingActiceRowBackgroundColor',
                'type'     => 'color',
                'url'      => true,
                'title'    => esc_html__('Active Row Background Color', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Background row color for active row in tiered pricing table.', 'woocommerce-ultimate-pricing'),
                'validate' => 'color',
                'default'  => '#2196F3',
                'required' => array('tieredPricingEnabled','equals','1'),
            ),
            array(
                'id'       =>'tieredPricingActiceRowColor',
                'type'     => 'color',
                'url'      => true,
                'title'    => esc_html__('Active Row Text Color', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Text row color for active row in tiered pricing table.', 'woocommerce-ultimate-pricing'),
                'validate' => 'color',
                'default'  => '#FFFFFF',
                'required' => array('tieredPricingEnabled','equals','1'),
            ),

            array(
                'id'       => 'tieredPricingTextsQuantity',
                'type'     => 'text',
                'title'    => esc_html__( 'Quantity Text', 'woocommerce-ultimate-pricing' ),
                'default'  => esc_html__( 'Quantity', 'woocommerce-ultimate-pricing' ),
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
            array(
                'id'       => 'tieredPricingTextsDiscount',
                'type'     => 'text',
                'title'    => esc_html__( 'Discount Text', 'woocommerce-ultimate-pricing' ),
                'default'  => esc_html__( 'Discount', 'woocommerce-ultimate-pricing' ),
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
            array(
                'id'       => 'tieredPricingTextsPrice',
                'type'     => 'text',
                'title'    => esc_html__( 'Price Text', 'woocommerce-ultimate-pricing' ),
                'default'  => esc_html__( 'Price', 'woocommerce-ultimate-pricing' ),
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),

            array(
                'id'       => 'tieredPricingPosition',
                'type'     => 'select',
                'title'    => esc_html__('Table Hook Position', 'woocommerce-shop-look'),
                'subtitle' => esc_html__('Specify the positon of the tiered pricing table. Use shortcode for dynamic product templates: [woocommerce_ultimate_pricing_tiered_pricing_table]', 'woocommerce-shop-look'),
                'default'  => 'woocommerce_product_meta_start',
                'options'  => array( 
                    'none' => esc_html__('None / Shortcode use', 'woocommerce-shop-look'),
                    'woocommerce_product_thumbnails' => esc_html__('Icon in Image', 'woocommerce-shop-look'),
                    'woocommerce_before_single_product' => esc_html__('Before Single Product', 'woocommerce-shop-look'),
                    'woocommerce_before_single_product_summary' => esc_html__('Before Single Product Summary', 'woocommerce-shop-look'),
                    'woocommerce_single_product_summary' => esc_html__('In Single Product Summary', 'woocommerce-shop-look'),
                    'woocommerce_product_meta_start' => esc_html__('Before Meta Information', 'woocommerce-shop-look'),
                    'woocommerce_product_meta_end' => esc_html__('After Meta Information', 'woocommerce-shop-look'),
                    'woocommerce_after_single_product_summary' => esc_html__('After Single Product Summary', 'woocommerce-shop-look'),
                    'woocommerce_after_single_product' => esc_html__('After Single Product', 'woocommerce-shop-look'),
                    'woocommerce_after_main_content' => esc_html__('After Main Product', 'woocommerce-shop-look'),
                ),
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
            array(
                'id'       => 'tieredPricingPriority',
                'type'     => 'spinner',
                'title'    => esc_html__( 'Table Hook Priority', 'woocommerce-shop-look' ),
                'min'      => '1',
                'step'     => '1',
                'max'      => '999',
                'default'  => '5',
                'required' => array('tieredPricingEnabled', 'equals', '1' ),
            ),
        )
    ) );

    // ToolTip
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Tooltip', 'woocommerce-ultimate-pricing' ),
        'id'         => 'tieredPricingDisplay',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'tieredPricingTooltipEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Tooltip', 'woocommerce-ultimate-pricing' ),
                'subtitle'    => esc_html__( 'Tooltip shows next to price with indication of current applied productDiscount rules.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'tieredPricingTooltipText',
                'type'     => 'text',
                'title'    => esc_html__( 'Tooltip Text', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__('Default tooltip text, that will show beside the price. Variables you can use:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountPercentage}}:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountRate}}:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{minQuantity}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{maxQuantity}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{oldPrice}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{newPrice}}', 'woocommerce-ultimate-pricing'),
                'default' => esc_html__('Save {{discountPercentage}} ({{discountRate}}) when buying more than {{minQuantity}} Quantities.', 'woocommerce-ultimate-pricing'), 
                'required' => array('tieredPricingTooltipEnabled', 'equals', '1'),
            ),
            array(
                'id'       => 'tieredPricingTooltipIconEnabled',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show tooltip Icon', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Shows an extra tooltip icon behind the badge.', 'woocommerce-ultimate-pricing' ),
                'default'  => 0,
                'required' => array('tieredPricingTooltipEnabled','equals','1'),
            ),
            array(
                'id'       => 'tieredPricingTooltipDisplay',
                'type'     => 'select',
                'title'    => esc_html__('Display', 'woocommerce-ultimate-pricing'),
                'multi'    => true,
                'subtitle' => esc_html__('Specify if it should show on single, category or both pages.', 'woocommerce-ultimate-pricing'),
                'options'  => array( 
                    'cart' => esc_html__('Cart Page', 'woocommerce-ultimate-pricing'),
                    'checkout' => esc_html('Checkout', 'woocommerce-ultimate-pricing'),
                ),
                'default'  => array('singleProduct'),
                'required' => array('tieredPricingTooltipIconEnabled','equals','1'),
            ),
            array(
                'id'       => 'tieredPricingTooltipIcon',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__( 'Tooltip Icon', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__('SVG icon or image HTML works.', 'woocommerce-ultimate-pricing'), 
                'args'   => array(
                    'teeny'            => false,
                ),
                'default' => '', 
                'required' => array('tieredPricingTooltipIconEnabled', 'equals', '1'),
            ),
            array(
                'id'       => 'tieredPricingTooltipIconWidth',
                'type'     => 'spinner',
                'title'    => esc_html__('Tooltip Icon Width (px)', 'woocommerce-ultimate-pricing'),
                'default'  => '25',
                'min'      => '1',
                'step'     => '1',
                'max'      => '99999',
                'required' => array('tieredPricingTooltipIconEnabled', 'equals', '1'),
            ),
        )
    ) );   

    // Badge
    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Badge', 'woocommerce-ultimate-pricing'),
        'id'         => 'tieredPricingBadge',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'tieredPricingBadgeEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Show  Bage', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Enable to show a  badge after the price.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'tieredPricingBadgeDisplay',
                'type'     => 'select',
                'title'    => esc_html__('Display', 'woocommerce-ultimate-pricing'),
                'multi'    => true,
                'subtitle' => esc_html__('Specify if it should show on single, category or both pages.', 'woocommerce-ultimate-pricing'),
                'options'  => array( 
                    'cart' => esc_html__('Cart Page', 'woocommerce-ultimate-pricing'),
                    'checkout' => esc_html('Checkout', 'woocommerce-ultimate-pricing'),
                ),
                'default'  => array('singleProduct', 'productCategory', 'cart', 'checkout'),
                'required' => array('tieredPricingBadgeEnabled','equals','1'),
            ),
            array(
                'id'       => 'tieredPricingBadgeText',
                'type'     => 'text',
                'title'    => esc_html__(' Bage Text', 'woocommerce-ultimate-pricing'),
                'subtitle' => esc_html__('Text that will show in the badge. Variables you can use:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountPercentage}}:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{discountRate}}:', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{minQuantity}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{maxQuantity}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{oldPrice}}', 'woocommerce-ultimate-pricing') . 
                    '<br>' . esc_html__('{{newPrice}}', 'woocommerce-ultimate-pricing'),
                'default' => esc_html__('Save {{discountPercentage}} ({{discountRate}}) when buying more than {{minQuantity}} Quantities.', 'woocommerce-ultimate-pricing'), 
                'required' => array('tieredPricingBadgeEnabled','equals','1'),
            ),
            array(
                'id'       => 'tieredPricingBadgeTooltip',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show tooltip text', 'woocommerce-ultimate-pricing' ),
                'subtitle' => esc_html__( 'Shows the configured tooltip text on badge hover.', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
                'required' => array('tieredPricingBadgeEnabled','equals','1'),
            ),
            array(
                'id'      => 'tieredPricingBadgeBackgroundColor',
                'type'      => 'color',
                'title'    => esc_html__(' Badge Background Color', 'woocommerce-ultimate-pricing'), 
                'default'   => '#F44336',
                'required' => array('tieredPricingBadgeEnabled','equals','1'),
            ),
            array(
                'id'      => 'tieredPricingBadgeTextColor',
                'type'      => 'color',
                'title'    => esc_html__(' Badge Text Color', 'woocommerce-ultimate-pricing'), 
                'default'   => '#ffffff',
                'required' => array('tieredPricingBadgeEnabled','equals','1'),
            ),
        )
    ));

    $tieredPricingCount = 10;
    if(isset($options['tieredPricingCount']) && !empty($options['tieredPricingCount'])) {
        $tieredPricingCount = $options['tieredPricingCount'];
    }
    
    for ($i=1; $i <= $tieredPricingCount; $i++) { 
        
        $customTitle = isset($options['tieredPricingRule' . $i . 'InternalName']) && !empty($options['tieredPricingRule' . $i . 'InternalName']) ? $options['tieredPricingRule' . $i . 'InternalName'] : esc_html__('Tiered Pricing ', 'woocommerce-ultimate-pricing') . $i;

        $framework::setSection( $opt_name, array(
            'title'      => $customTitle,
            'id'         => 'tieredPricingule' . $i,
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'tieredPricingRule' . $i . 'Enabled',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Enable', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__( 'Enable this tieredPricingule.', 'woocommerce-ultimate-pricing' ),
                    'default'  => 0,
                ),
                array(
                    'id'       => 'tieredPricingRule' . $i . 'InternalName',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Internal Name', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this Rule an internal name.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'tieredPricingRule' . $i . 'Type',
                    'type'     => 'select', 
                    'title'    => esc_html__('Discount Type', 'woocommerce-ultimate-pricing'),
                    'options'  => array(
                        'percentage' => esc_html__('Percentage Discount', 'woocommerce-ultimate-pricing'),
                        'fixed' => esc_html__('Fixed Amount Discount', 'woocommerce-ultimate-pricing'),
                        'fixed_total' => esc_html__('Fixed Total Amount', 'woocommerce-ultimate-pricing'),
                    ),
                    'default'  => 'percentage',
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'tieredPricingRule' . $i . 'Discounts',
                    'type'     => 'multi_text',
                    'title'    => esc_html__('Tiered Pricing Discounts', 'woocommerce-delivery'),
                    'subtitle' => esc_html__('Quantity <> Discount. Only one tier per row! Foramt: Quantity|Discount (use | as separator). First quantity then discount. Example: 5|20 = When 5 or more quantity choosen, then 5% or $5 discount is granted.', 'woocommerce-delivery'),
                    'default'  => array(),
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),

                // Apply For section
                array(
                    'id'        => 'tieredPricingRule' . $i . 'Roles',
                    'type'      => 'select',
                    'data'      => 'roles',
                    'multi'     => true,
                    'title'     => esc_html__('Apply for User Roles ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain user roles only.', 'woocommerce-ultimate-pricing'),
                    'required'  => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'tieredPricingRule' . $i . 'Categories',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_cat')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Categories', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on product categories only.', 'woocommerce-ultimate-pricing'),
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'tieredPricingRule' . $i . 'Tags',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_tag')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Tags', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on product tags only.', 'woocommerce-ultimate-pricing'),
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'tieredPricingRule' . $i . 'Products',
                    'type'      => 'select',
                    'data'      => 'posts',
                    'args'      => array('post_type' => array('product'), 'posts_per_page' => -1),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Products ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain products only', 'woocommerce-ultimate-pricing'),
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'tieredPricingRule' . $i . 'Reviews',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Rewiews Written', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply this discount rule only when certain amount of reviews have been written. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'tieredPricingRule' . $i . 'Orders',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Orders reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply this discount rule only when certain amount of orders have been made. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'tieredPricingRule' . $i . 'DateRange',
                    'type'     => 'text',
                    'class'    => 'woocommerce-ultimate-pricing-datepicker',
                    'title'    => esc_html__('Start & End Date', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Specify a date from when this discount should get applied on to.', 'woocommerce-ultimate-pricing'),
                    'default'  => '',
                    'required' => array('tieredPricingRule' . $i . 'Enabled','equals', '1' ),
                ),
           )
        ) );
    }

     // Cart Fees
    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'Cart Fees', 'woocommerce-ultimate-pricing' ),
        'id'     => 'cartFees',
        'icon'   => 'el el-tags',
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'General', 'woocommerce-ultimate-pricing' ),
        'id'         => 'cartFeesGeneral',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'cartFeesEnabled',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Cart Fees', 'woocommerce-ultimate-pricing' ),
                'default'  => 1,
            ),
            array(
                'id'       => 'cartFeesCount',
                'type'     => 'spinner',
                'title'    => esc_html__('Product Discount Rules Count', 'woocommerce-ultimate-pricing'), 
                'subtitle' => esc_html__('Limit the number of global product pricing rules to decrease the load time. Reload the settings panel after changing.', 'woocommerce-ultimate-pricing'), 
                'default'  => '10',
                'min'      => '1',
                'step'     => '1',
                'max'      => '200',
                'required' => array('cartFeesEnabled', 'equals', '1' ),
            ),
        )
    ) );

    $cartFeesCount = 10;
    if(isset($options['cartFeesCount']) && !empty($options['cartFeesCount'])) {
        $cartFeesCount = $options['cartFeesCount'];
    }
    
    for ($i=1; $i <= $cartFeesCount; $i++) { 
        
        $customTitle = isset($options['cartFeesRule' . $i . 'InternalName']) && !empty($options['cartFeesRule' . $i . 'InternalName']) ? $options['cartFeesRule' . $i . 'InternalName'] : esc_html__('Scenario ', 'woocommerce-ultimate-pricing') . $i;

        $framework::setSection( $opt_name, array(
            'title'      => $customTitle,
            'id'         => 'cartFeesRule' . $i,
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'cartFeesRule' . $i . 'Enabled',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Enable', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__( 'Enable this cartFeesRule.', 'woocommerce-ultimate-pricing' ),
                    'default'  => 0,
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'Title',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Title', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this cart fee Rule a custom title, that can be used in the tooltip for example.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'InternalName',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Internal Name', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Give this cart fee rule an internal name.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'TooltipText',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Tooltip Text', 'woocommerce-ultimate-pricing' ),
                    'subtitle' => esc_html__('Set a custom tooltip text to override the default tooltip text.', 'woocommerce-ultimate-pricing'), 
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'cartFeesRule' . $i . 'Type',
                    'type'     => 'select', 
                    'title'    => esc_html__('Fee Type', 'woocommerce-ultimate-pricing'),
                    'options'  => array(
                        'percentage' => esc_html__('Percentage Fee (Cart Subotal)', 'woocommerce-ultimate-pricing'),
                        'fixed' => esc_html__('Fixed Amount Fee', 'woocommerce-ultimate-pricing'),
                        'fixedTotal' => esc_html__('Fixed Amount Total', 'woocommerce-ultimate-pricing'),
                        'percentageTotalAppliedWithTax' => esc_html__('Percentage Amount of Applied Items with Tax', 'woocommerce-ultimate-pricing'),
                        'percentageTotalAppliedWithoutTax' => esc_html__('Percentage Amount of Applied Items without Tax', 'woocommerce-ultimate-pricing'),
                    ),
                    'default'  => 'percentage',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                    array(
                        'id'       => 'cartFeesRule' . $i . 'PercentageFee',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Fee', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartFeesRule' . $i . 'Enabled','equals', '1'), array('cartFeesRule' . $i . 'Type', 'equals', 'percentage') ),
                    ),
                    array(
                        'id'       => 'cartFeesRule' . $i . 'PercentageTotalAppliedWithTaxPercentage',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Fee', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartFeesRule' . $i . 'Enabled','equals', '1'), array('cartFeesRule' . $i . 'Type', 'equals', 'percentageTotalAppliedWithTax') ),
                    ),
                    array(
                        'id'       => 'cartFeesRule' . $i . 'PercentageTotalAppliedWithoutTaxPercentage',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Percentage Fee', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '100',
                        'required' => array( array('cartFeesRule' . $i . 'Enabled','equals', '1'), array('cartFeesRule' . $i . 'Type', 'equals', 'percentageTotalAppliedWithoutTax') ),
                    ),
                    array(
                        'id'       => 'cartFeesRule' . $i . 'FixedFee',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Fixed Amount Fee', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '9999999999999',
                        'required' => array( array('cartFeesRule' . $i . 'Enabled','equals', '1'), array('cartFeesRule' . $i . 'Type', 'equals', 'fixed') ),
                    ),
                    array(
                        'id'       => 'cartFeesRule' . $i . 'FixedTotal',
                        'type'     => 'spinner',
                        'title'    => esc_html__('Fixed Total Amount', 'woocommerce-ultimate-pricing'),
                        'subtitle'    => esc_html__('The total price of the cart.', 'woocommerce-ultimate-pricing'),
                        'default'  => '10',
                        'min'      => '0',
                        'step'     => '1',
                        'max'      => '9999999999999',
                        'required' => array( array('cartFeesRule' . $i . 'Enabled','equals', '1'), array('cartFeesRule' . $i . 'Type', 'equals', 'fixedTotal') ),
                    ),

                // Apply For section
                array(
                    'id'        => 'cartFeesRule' . $i . 'Roles',
                    'type'      => 'select',
                    'data'      => 'roles',
                    'multi'     => true,
                    'title'     => esc_html__('Apply for User Roles ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Only add this tab to specific products.', 'woocommerce-ultimate-pricing'),
                    'required'  => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'Level',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when User is at least Level X', 'woocommerce-ultimate-pricing'),
                    'subtitle' => __('You need our <a href="https://www.welaunch.io/en/product/woocommerce-reward-points/" target="_blank">WooCommerce Reward Points plugin</a> for this. 0 means disabled.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => $levelsMax,
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'CartItemCount',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Items are in Cart', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of items are in cart. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'CartQuantityCount',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Quantity Count is Cart', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain quantity is in cart. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'CartSubtotal',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Cart Subtotal reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when a specific cart subtotal is reached. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'Reviews',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Rewiews Written', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of reviews have been written. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'       => 'cartFeesRule' . $i . 'Orders',
                    'type'     => 'spinner',
                    'title'    => esc_html__('Apply when XX Orders reached', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Apply discount only when certain amount of orders have been made. Set to 0 when not used.', 'woocommerce-ultimate-pricing'),
                    'default'  => '0',
                    'min'      => '0',
                    'step'     => '1',
                    'max'      => '9999999999999',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'       => 'cartFeesRule' . $i . 'DateRange',
                    'type'     => 'text',
                    'class'    => 'woocommerce-ultimate-pricing-datepicker',
                    'title'    => esc_html__('Start & End Date', 'woocommerce-ultimate-pricing'),
                    'subtitle' => esc_html__('Specify a date from when this discount should get applied on to.', 'woocommerce-ultimate-pricing'),
                    'default'  => '',
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),

                array(
                    'id'        => 'cartFeesRule' . $i . 'Categories',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_cat')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Categories', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain product categories only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'cartFeesRule' . $i . 'Tags',
                    'type'      => 'select',
                    'data'      => 'categories',
                    'args'      => array('taxonomy' => array('product_tag')),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Product Tags', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain product tags only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
                array(
                    'id'        => 'cartFeesRule' . $i . 'Products',
                    'type'      => 'select',
                    'data'      => 'posts',
                    'args'      => array('post_type' => array('product'), 'posts_per_page' => -1),
                    'ajax'      => true,
                    'multi'     => true,
                    'title'     => esc_html__('Apply for Products ', 'woocommerce-ultimate-pricing'), 
                    'subtitle'  => esc_html__('Apply this discount rule on certain products only. This checks costs performance.', 'woocommerce-ultimate-pricing'),
                    'required' => array('cartFeesRule' . $i . 'Enabled','equals', '1' ),
                ),
           )
        ) );
    }